from datetime import datetime
from enum import Enum
from peewee import (
    Model,
    SqliteDatabase,
    CharField,
    TextField,
    DateTimeField,
    ForeignKeyField,
)

db = SqliteDatabase("tasks.db")


class TaskStatus(Enum):
    ZERO = "zero"
    WIP = "wip"
    BLOCKED = "blocked"
    DONE = "done"


class BaseModel(Model):
    class Meta:
        database = db


class Category(BaseModel):
    name = CharField(unique=True)

    def __str__(self):
        return self.name


class Task(BaseModel):
    text = TextField()
    status = CharField(
        choices=[(status.value, status.name) for status in TaskStatus],
        default=TaskStatus.ZERO.value,
    )
    due = DateTimeField(null=True)
    category = ForeignKeyField(Category, backref="tasks", null=True)
    type = CharField()
    created_at = DateTimeField(default=datetime.now)
    updated_at = DateTimeField(default=datetime.now)

    def save(self, *args, **kwargs):
        self.updated_at = datetime.now()
        return super(Task, self).save(*args, **kwargs)


def initialize_db():
    db.connect()
    db.create_tables([Category, Task])
    if not Category.select().exists():
        Category.create(name="main")
    db.close()


if __name__ == "__main__":
    initialize_db()
